from ambition_ae.constants import AE_TMG_ACTION
from django.conf import settings
from django.views.generic import TemplateView
from edc_action_item.models.action_item import ActionItem
from edc_constants.constants import CLOSED, OPEN, NEW
from edc_dashboard.view_mixins import EdcViewMixin
from edc_navbar import NavbarViewMixin
from django.contrib.sites.shortcuts import get_current_site
from django.db.models.aggregates import Count


class HomeView(EdcViewMixin, NavbarViewMixin, TemplateView):

    template_name = (
        f"ambition_dashboard/bootstrap{settings.EDC_BOOTSTRAP}/tmg/home.html"
    )
    navbar_name = "ambition_dashboard"
    navbar_selected_item = "tmg_home"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)

        # summarize closed reports by site
        summary = (
            ActionItem.objects.filter(action_type__name=AE_TMG_ACTION, status=CLOSED)
            .values("site__name")
            .annotate(count=Count("status"))
            .order_by("site__name")
        )

        # summarize new and open for notice
        qs = (
            ActionItem.objects.filter(
                action_type__name=AE_TMG_ACTION, status__in=[NEW, OPEN]
            )
            .exclude(site__name=get_current_site(request=self.request).name)
            .values("status", "site__name")
            .annotate(items=Count("status"))
        )
        notices = []
        for item in qs.order_by("status", "site__name"):
            notices.append(
                [item.get("site__name"), item.get("status"), item.get("items")]
            )

        new_count = qs.filter(
            status=NEW, site__name=get_current_site(request=self.request).name
        ).count()
        open_count = ActionItem.objects.filter(
            action_type__name=AE_TMG_ACTION,
            status=OPEN,
            site__name=get_current_site(request=self.request).name,
        ).count()
        closed_count = ActionItem.objects.filter(
            action_type__name=AE_TMG_ACTION,
            status=CLOSED,
            site__name=get_current_site(request=self.request).name,
        ).count()
        total_closed_count = ActionItem.objects.filter(
            action_type__name=AE_TMG_ACTION, status=CLOSED
        ).count()
        context.update(
            {
                "new_count": new_count,
                "open_count": open_count,
                "closed_count": closed_count,
                "total_closed_count": total_closed_count,
                "summary": summary,
                "notices": notices,
            }
        )
        return context
